#!/bin/bash

grid_resolution=48x36x39
an=clim
veget=0


#######################################################
# Default path for the input files
# Will be overpassed using wget if not available
dirinit=/u/lmdz/WWW/LMDZ_Init
#######################################################


\rm -f tmp.*
if [ $veget = 0 ] ; then
   optveget=""
else
   optveget="-v true"
fi


#########################################################################
# Model location
#########################################################################
if [ `pwd | grep modipsl` ] ; then
   MODEL=`pwd | sed -e 's/.modipsl/ /' | awk ' { print $1 } '`
else
   echo Mettre emplacement du modele a la main
fi
SIMU=`pwd`
if [ ! -f run.def -o ! -f physiq.def -o ! -f gcm.def ] ; then
    echo Il n y a pas de fichier run.def ou physiq.def ou gcm.def dans le
    echo repertoire $SIMU. Vous pouvez en recuperer sur
    echo $MODEL/modipsl/modeles/LMDZ5/DefLists
    exit
fi

echo '#############################################################'
echo '# Model Compilation                                          '
echo '#############################################################'

cd $MODEL/modipsl/modeles/LMDZ5
for mod in gcm ce0l ; do
   ./makelmdz -d $grid_resolution $optveget $mod
   if [ -f $mod.e ] ; then
      mv $mod.e $SIMU/
   else
      echo Echec pour la compilation de lmdz ; exit
   fi
done


echo '###############################################################'
echo '# Create initial state (start.nc and startphy.nc) and          '
echo '# boundary conditions (SSTs ...) for the LMDZ global           '
echo '# climate model.                                               '
echo '#                                                              '
echo '...............................................................'
echo '# 1. Geting input files from the web                           '
echo '...............................................................'
cd $SIMU

# Get files either by links or wget
if [ -d $dirinit ] ; then
   get="ln -sf $dirinit/"
else
   get="wget http://www.lmd.jussieu.fr/~lmdz/LMDZ_Init/"
fi

if [ "$an" = "clim" ] ; then
   suf=1x1_clim
else
   suf=360x180_$an
fi


# If input files are already there, do not download
if [ -f amipbc_sst_$suf.nc ] ;  then
   echo Les fichiers d entree sont deja la
else
   ${get}Albedo.nc
   ${get}ECDYN.nc
   ${get}Relief.nc
   ${get}Rugos.nc
   ${get}landiceref.nc
   ${get}amipbc_sic_$suf.nc
   ${get}amipbc_sst_$suf.nc
fi

if [ -f amipbc_sst_$suf.nc ] ;  then
    ln -sf ECDYN.nc ECPHY.nc
    ln -sf amipbc_sic_$suf.nc amipbc_sic_1x1.nc
    ln -sf amipbc_sst_$suf.nc amipbc_sst_1x1.nc
else
    echo Les fichiers n ont pas ete telecharges correctement ; exit
fi


echo '...............................................................'
echo ' 2. Running ce0l.e  (output listing in ce0l.out)               '
echo '...............................................................'
./ce0l.e > ce0l.out 2>&1

cat <<eod>| tmp.jnl
use grilles_gcm.nc
let rel=if (abs(grille_s-1) gt 0.5) then phis
shade/pal=land_sea_values rel ; go land
let deep=if (rel lt 0.1) then rel
shade/pal=blue/o deep
quit
eod
ferret -batch tmp.ps -nojnl -script  tmp.jnl
ps2epsi tmp.ps ; epstopdf tmp.ps ; \mv tmp.pdf grille.pdf


if [ $veget = 0 ] ; then
    echo Sans vegetation
else

echo '###############################################################'
echo '# Run a first simulation which will create the intial state    '
echo '# for ORCHIDEE (start_sech.nc)                                 '
echo '...............................................................'
echo '#  1. Geting input files from the web for Orchidee             '
echo '...............................................................'

\rm PFTmap_IPCC_2000.nc cartepente2d_15min.nc routing.nc lai2D.nc soils_param.nc
${get}PFTmap_IPCC_2000.nc 
${get}cartepente2d_15min.nc
#ln -sf PFTmap_IPCC_2000.nc pft_new.nc
ln -sf PFTmap_IPCC_2000.nc PFTmap.nc
${get}routing.nc
${get}lai2D.nc
${get}soils_param.nc


# Modifying .def files for a first 1-day simulation
\mv -f config.def config.orig
sed -e 's/VEGET=.*.$/VEGET=y/' config.orig >| config.def
\mv -f run.def run.orig
sed -e 's/nday=.*.$/nday=1/' run.orig >| run.def
\mv -f orchidee.def orchidee.orig
#sed -e 's/^SECHIBA_restart_in=.*./SECHIBA_restart_in=NONE/' -e 's/^.*.HIBA_rest_out.*.$/SECHIBA_rest_out=restart_sech.nc/' orchidee.orig >| orchidee.def
sed -e 's/^SECHIBA_restart_in=.*./SECHIBA_restart_in=NONE/' -e 's/^.*.HIBA_rest_out.*.$/SECHIBA_rest_out=sechiba_rest_out.nc/' orchidee.orig >| orchidee.def


echo '...............................................................'
echo ' 2. Running gcm.e for 1 day                                    '
echo '...............................................................'
./gcm.e > listing0   2>&1
echo '###############################################################'

# Saving output files and modifying .def files
mv sechiba_rest_out.nc sechiba_rest_in.nc
for i in stomate_history sechiba_out  ; do mv $i.nc $i.0.nc ; done
\cp -f run.orig run.def
#sed -e 's/^SECHIBA_restart_in=.*./SECHIBA_restart_in=start_sech.nc/' -e 's/^.*.HIBA_rest_out.*.$/SECHIBA_rest_out=restart_sech.nc/' orchidee.orig >| orchidee.def
sed -e 's/^SECHIBA_restart_in=.*./SECHIBA_restart_in=sechiba_rest_in.nc/' -e 's/^.*.HIBA_rest_out.*.$/SECHIBA_rest_out=sechiba_rest_out.nc/' orchidee.orig >| orchidee.def

fi

echo '###############################################################'
echo Here the scripts stops to let the user the great pleasure to
echo 'run ./gcm.e on his own. Hoping you ll enjoy it'
exit
gcm.e
